==> spl_transpiler-0.1.6.tar.gz: spl_transpiler-0.1.6/src/commands/cmd_where/spl.rs <==
use crate::commands::spl::{SplCommand, SplCommandOptions};
use crate::spl::ast::{Expr, ParsedCommandOptions};
use crate::spl::parser::expr;
use crate::spl::python::impl_pyclass;
use nom::combinator::map;
use nom::IResult;
use pyo3::prelude::*;
//   // where <predicate-expression>
//   def where[_: P]: P[WhereCommand] = "where" ~ expr map WhereCommand

#[derive(Debug, PartialEq, Clone, Hash)]
#[pyclass(frozen, eq, hash)]
pub struct WhereCommand {
    #[pyo3(get)]
    pub expr: Expr,
}
impl_pyclass!(WhereCommand { expr: Expr });

#[derive(Debug, Default)]
pub struct WhereParser {}
pub struct WhereCommandOptions {}

impl SplCommandOptions for WhereCommandOptions {}

impl TryFrom<ParsedCommandOptions> for WhereCommandOptions {
    type Error = anyhow::Error;

    fn try_from(_value: ParsedCommandOptions) -> Result<Self, Self::Error> {
        Ok(Self {})
    }
}

impl SplCommand<WhereCommand> for WhereParser {
    type RootCommand = crate::commands::WhereCommandRoot;
    type Options = WhereCommandOptions;

    fn parse_body(input: &str) -> IResult<&str, WhereCommand> {
        map(expr, |v| WhereCommand { expr: v })(input)
    }
}

#[cfg(test)]
mod tests {
    use super::*;
    use crate::spl::ast;
    use crate::spl::parser::pipeline;
    use crate::spl::utils::test::*;

    //
    //   test("where isnull(reason)") {
    //     p(pipeline(_), Pipeline(Seq(
    //       WhereCommand(
    //         Call(
    //           "isnull",Seq(
    //             Field("reason")
    //           )
    //         )
    //       )
    //     )))
    //   }
    #[test]
    fn test_pipeline_where_6() {
        assert_eq!(
            pipeline("where isnull(reason)"),
            Ok((
                "",
                ast::Pipeline {
                    commands: vec![WhereCommand {
                        expr: _call!(isnull(ast::Field::from("reason"))).into()
                    }
                    .into()],
                }
            ))
        )
    }
}

==> spl_transpiler-0.1.7.tar.gz: spl_transpiler-0.1.7/src/commands/cmd_where/spl.rs <==
use crate::commands::spl::{SplCommand, SplCommandOptions};
use crate::spl::ast::{Expr, ParsedCommandOptions};
use crate::spl::parser::logical_expression;
use crate::spl::python::*;
use nom::combinator::map;
use nom::IResult;
use pyo3::prelude::*;
//   // where <predicate-expression>
//   def where[_: P]: P[WhereCommand] = "where" ~ expr map WhereCommand

#[derive(Debug, PartialEq, Clone, Hash)]
#[pyclass(frozen, eq, hash)]
pub struct WhereCommand {
    #[pyo3(get)]
    pub expr: Expr,
}
impl_pyclass!(WhereCommand { expr: Expr });

#[derive(Debug, Default)]
pub struct WhereParser {}
pub struct WhereCommandOptions {}

impl SplCommandOptions for WhereCommandOptions {}

impl TryFrom<ParsedCommandOptions> for WhereCommandOptions {
    type Error = anyhow::Error;

    fn try_from(_value: ParsedCommandOptions) -> Result<Self, Self::Error> {
        Ok(Self {})
    }
}

impl SplCommand<WhereCommand> for WhereParser {
    type RootCommand = crate::commands::WhereCommandRoot;
    type Options = WhereCommandOptions;

    fn parse_body(input: &str) -> IResult<&str, WhereCommand> {
        map(logical_expression, |v| WhereCommand { expr: v })(input)
    }
}

#[cfg(test)]
mod tests {
    use super::*;
    use crate::spl::ast;
    use crate::spl::parser::pipeline;
    use crate::spl::utils::test::*;

    //
    //   test("where isnull(reason)") {
    //     p(pipeline(_), Pipeline(Seq(
    //       WhereCommand(
    //         Call(
    //           "isnull",Seq(
    //             Field("reason")
    //           )
    //         )
    //       )
    //     )))
    //   }
    #[test]
    fn test_pipeline_where_6() {
        assert_eq!(
            pipeline("where isnull(reason)"),
            Ok((
                "",
                ast::Pipeline {
                    commands: vec![WhereCommand {
                        expr: _call!(isnull(ast::Field::from("reason"))).into()
                    }
                    .into()],
                }
            ))
        )
    }
}
